pecos.qeclib.steane.gates\_tq
=============================

.. automodule:: pecos.qeclib.steane.gates_tq



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeclib.steane.gates_tq.transversal_tq
